# FieldOptions5

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**time_zone** | **str** |  | [optional] 
**date_format** | [**FieldOptions4DateFormat**](FieldOptions4DateFormat.md) |  | [optional] 
**time_format** | [**FieldOptions5TimeFormat**](FieldOptions5TimeFormat.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

